function [D] = analytical_value_DKL(distr1,distr2,par1,par2)
%function [D] = analytical_value_DKL(distr1,distr2,par1,par2)
%Analytical value (D) of the Kullback-Leibler divergence for the given distributions. See also 'quick_test_DKL.m'.
%
%INPUT:
%   distr1 : name of distribution-1; 'normal'.
%   distr2 : name of distribution-2; 'normal'.
%   par1   : parameters of distribution-1 (structure),
%            distr1 = 'normal': par1.e = expectation1, par1.cov = covariance matrix1.
%   par2   : parameters of distribution-2 (structure),
%            distr2 = 'normal': par2.e = expectation2, par2.cov = covariance matrix2.

%Copyright (C) 2012-2013 Zoltan Szabo ("http://www.gatsby.ucl.ac.uk/~szabo/", "zoltan (dot) szabo (at) gatsby (dot) ucl (dot) ac (dot) uk")
%
%This file is part of the ITE (Information Theoretical Estimators) toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

if strcmp(distr1,'normal') && strcmp(distr2,'normal')
    %covariance matrices, expectations:
        e1 = par1.e; cov1 = par1.cov;
        e2 = par2.e; cov2 = par2.cov;
    d = length(e1);
                
    diffe = e1 - e2;
    invSigma2 = inv(cov2);
    D = 1/2 * ( log(det(cov2)/det(cov1)) + trace(invSigma2*cov1)  + diffe.' * invSigma2 * diffe - d);
else
    error('Distribution=?'); 
end
