function [D] = analytical_value_DRenyi(distr1,distr2,alpha_D,par1,par2)
%function [D] = analytical_value_DRenyi(distr1,distr2,alpha_D,par1,par2)
%Analytical value (D) of the Renyi divergence for the given distributions. See also 'quick_test_DRenyi.m'.
%
%INPUT:
%   distr1 : name of distribution-1; 'normal'.
%   distr2 : name of distribution-2; 'normal'.
%  alpha_D : parameter of Renyi divergence.
%   par1   : parameters of distribution-1 (structure),
%            distr1 = 'normal': par1.e = expectation1, par1.cov = covariance matrix1.
%   par2   : parameters of distribution-2 (structure),
%            distr2 = 'normal': par2.e = expectation2, par2.cov = covariance matrix2.

%Copyright (C) 2012-2013 Zoltan Szabo ("http://www.gatsby.ucl.ac.uk/~szabo/", "zoltan (dot) szabo (at) gatsby (dot) ucl (dot) ac (dot) uk")
%
%This file is part of the ITE (Information Theoretical Estimators) toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

if strcmp(distr1,'normal') && strcmp(distr2,'normal')
    %covariance matrices, expectations:
        e1 = par1.e; cov1 = par1.cov;
        e2 = par2.e; cov2 = par2.cov;
        
    mixcov = alpha_D * cov2 + (1-alpha_D) * cov1;
    diffe = e1 - e2;
    %Renyi divergence (Manuel Gil. On Renyi Divergence Measures for Continuous Alphabet Sources. Phd Thesis, Queen’s University, 2011):
        D = alpha_D * ( 1/2 *diffe.' * inv(mixcov) * diffe  - 1 / (2*alpha_D*(alpha_D-1)) * log( abs(det(mixcov)) / (det(cov1)^(1-alpha_D) * det(cov2)^(alpha_D)) )); 
    %Kullback-Leibler divergence (verification, in the alpha_D->1 limit: KL div. = Renyi div.):
        %d = size(cov1,1);
        %D = 1/2 * ( log(det(cov2)/det(cov1)) + trace(inv(cov2)*cov1)  + diffe.' * inv(cov2) * diffe - d);
else
    error('Distribution=?'); 
end




